@@ -128,12 +128,11 @@ class Repo(object):
         updater = Updater(self.dvc_dir)
 
         flist = [
-            self.state.state_file,
             self.lock.lock_file,
             self.config.config_local_file,
             updater.updater_file,
             updater.lock.lock_file,
-        ] + self.state.temp_files
+        ] + self.state.files
 
         if self.cache.local.cache_dir.startswith(self.root_dir):
             flist += [self.cache.local.cache_dir]
@@ -181,7 +180,7 @@ class Repo(object):
 
     def used_cache(
         self,
-        target=None,
+        targets=None,
         all_branches=False,
         active=True,
         with_deps=False,
@@ -216,18 +215,22 @@ class Repo(object):
         for branch in self.brancher(
             all_branches=all_branches, all_tags=all_tags
         ):
-            if target:
-                if recursive and os.path.isdir(target):
-                    stages = self.stages(target)
-                else:
-                    stages = self.collect(target, with_deps=with_deps)
+            if targets:
+                stages = []
+                for target in targets:
+                    if recursive and os.path.isdir(target):
+                        stages.extend(self.stages(target))
+                    else:
+                        stages.extend(
+                            self.collect(target, with_deps=with_deps)
+                        )
             elif active:
                 stages = self.active_stages()
             else:
                 stages = self.stages()
 
             for stage in stages:
-                if active and not target and stage.locked:
+                if active and not targets and stage.locked:
                     logger.warning(
                         "DVC-file '{path}' is locked. Its dependencies are"
                         " not going to be pushed/pulled/fetched.".format(
